@@ -1,15 +1,15 @@
 
 module Config
 
-  RUBY_VERSION == "1.6.5" or
-    raise "ruby lib version (1.6.5) doesn't match executable version (#{RUBY_VERSION})"
+  RUBY_VERSION == "1.6.6" or
+    raise "ruby lib version (1.6.6) doesn't match executable version (#{RUBY_VERSION})"
 
 # This file was created by configrb when ruby was built. Any changes
 # made to this file will be lost the next time ruby is built.
   DESTDIR = '' if not defined? DESTDIR
   CONFIG = {}
   TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.6/i386\-msdosdjgpp\Z', '')
-  CONFIG["srcdir"] = "/pub/ruby/16/dist/ruby-1.6.5"
+  CONFIG["srcdir"] = "/pub/ruby/16/dist/ruby-1.6.6"
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "ruby"
   CONFIG["EXEEXT"] = ".exe"
@@ -19,7 +19,7 @@ module Config
   CONFIG["CXXFLAGS"] = ""
   CONFIG["FFLAGS"] = ""
   CONFIG["LDFLAGS"] = ""
-  CONFIG["LIBS"] = "-lm "
+  CONFIG["LIBS"] = "-lm"
   CONFIG["exec_prefix"] = "$(prefix)"
   CONFIG["bindir"] = "$(exec_prefix)/bin"
   CONFIG["sbindir"] = "$(exec_prefix)/sbin"
@@ -35,7 +35,7 @@ module Config
   CONFIG["mandir"] = "$(prefix)/man"
   CONFIG["MAJOR"] = "1"
   CONFIG["MINOR"] = "6"
-  CONFIG["TEENY"] = "5"
+  CONFIG["TEENY"] = "6"
   CONFIG["host"] = "i586-pc-msdosdjgpp"
   CONFIG["host_alias"] = "i586-pc-msdosdjgpp"
   CONFIG["host_cpu"] = "i586"
@@ -76,7 +76,7 @@ module Config
   CONFIG["STRIP"] = "strip"
   CONFIG["EXTSTATIC"] = ""
   CONFIG["setup"] = "Setup.dj"
-  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/dist/ruby-1.6.5/dobj -rfake"
+  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/dist/ruby-1.6.6/dobj -rfake"
   CONFIG["PREP"] = "fake.rb"
   CONFIG["LIBRUBY_LDSHARED"] = "ld"
   CONFIG["LIBRUBY_DLDFLAGS"] = ""
@@ -93,13 +93,13 @@ module Config
   CONFIG["MAINLIBS"] = ""
   CONFIG["arch"] = "i386-msdosdjgpp"
   CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
-  CONFIG["configure_args"] = "--target=i386-msdosdjgpp --host=i586-pc-msdosdjgpp --build=i586-pc-linux-gnu"
+  CONFIG["configure_args"] = "--srcdir=.. --target=i386-msdosdjgpp --host=i586-pc-msdosdjgpp --build=i586-pc-linux-gnu --cache=../../config.cache-djgpp"
   CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
   CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
   CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
   CONFIG["sitearchdir"] = "$(sitelibdir)/$(arch)"
-  CONFIG["compile_dir"] = "/pub/ruby/16/dist/ruby-1.6.5/dobj"
+  CONFIG["compile_dir"] = "/pub/ruby/16/dist/ruby-1.6.6/dobj"
   MAKEFILE_CONFIG = {}
   CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
   def Config::expand(val)
